@@ -1,12 +1,12 @@
 package Ubic::AccessGuard;
-BEGIN {
-  $Ubic::AccessGuard::VERSION = '1.38_01';
+{
+  $Ubic::AccessGuard::VERSION = '1.43_01';
 }
 
 use strict;
 use warnings;
 
-# ABSTRACT: class which guards simple service operations
+# ABSTRACT: guard for operations with temporarily different effective uid
 
 
 use Params::Validate;
@@ -16,36 +16,33 @@ use Carp;
 use Scalar::Util qw(weaken);
 use Try::Tiny;
 
-# AccessGuard is actually a singleton - there can't be two guards for two different services, because process can't have two euids.
+# AccessGuard is actually a singleton - there can't be two different guards, since process can't have two euids.
 # So we keep weakref to any created AccessGuard.
 my $ag_ref;
 
 
 sub new {
     my $class = shift;
-    my ($service) = validate_pos(@_, { isa => 'Ubic::Service' });
+    my ($credentials) = validate_pos(@_, { isa => 'Ubic::Credentials' });
 
     if ($ag_ref) {
         # oops, another AccessGuard already exists
         my $ag = $$ag_ref;
-        if ($ag->{service_name} eq $service->full_name) {
-            # it's for the same service, ok
+        if ($ag->{credentials}->eq($credentials)) {
+            # new guard is the same as old guard
             return $ag;
         }
         else {
-            croak "Can't create AccessGuard for ".$service->full_name.", there is already another AccessGuard for ".$ag->{service_name};
+            croak "Can't create AccessGuard for ".$credentials->as_string.", there is already another AccessGuard for ".$ag->{credentials}->as_string;
         }
     }
 
-    my $creds = Ubic::Credentials->new(service => $service);
-
     my $self = bless {
-        service_name => $service->full_name,
-        creds => $creds,
+        credentials => $credentials,
     } => $class;
 
     try {
-        $creds->set_effective;
+        $credentials->set_effective;
     }
     catch {
         die result('unknown', "$_");
@@ -61,7 +58,7 @@ sub DESTROY {
     my $self = shift;
     local $@;
 
-    $self->{creds}->reset_effective;
+    $self->{credentials}->reset_effective;
 }
 
 
@@ -72,36 +69,43 @@ __END__
 
 =head1 NAME
 
-Ubic::AccessGuard - class which guards simple service operations
+Ubic::AccessGuard - guard for operations with temporarily different effective uid
 
 =head1 VERSION
 
-version 1.38_01
+version 1.43_01
 
 =head1 SYNOPSIS
 
     use Ubic::AccessGuard;
 
-    $guard = Ubic::AccessGuard->new($service); # change effective uid and effective gid to $service->user and $service->group
-    undef $guard; # change them back
+    # change effective uid and effective gid to $credentials
+    $guard = Ubic::AccessGuard->new($credentials);
+
+    # change them back
+    undef $guard;
 
 =head1 DESCRIPTION
 
-Ubic::AccessGuard sets effective uid to specified service's user id if neccesary, and restore it back on destruction.
+Ubic::AccessGuard temporarily changes effective uid and gid, and restore it back on destruction.
 
 It's usage is limited, because when effective uid is not equal to real uid, perl automatically turns on tainted mode.
 Because of this, only tainted-safe code should be called when AccessGuard is active.
-L<Ubic> doesn't start services under this guard, but uses it when acquiring locks and writing service status files.
+Ubic doesn't start services under this guard, but uses it when acquiring locks and writing service status files.
+
+=head1 INTERFACE SUPPORT
+
+This is considered to be a non-public class. Its interface is subject to change without notice.
 
 =head1 METHODS
 
 =over
 
-=item C<< new($service) >>
+=item C<< new($credentials) >>
 
 Construct new access guard object.
 
-User will be changed into user apporpriate for running C<$service>. It will be changed back on guard's desctruction.
+User and group will be changed into given C<$credentials>. It will be changed back on guard's desctruction.
 
 =back
 
