@@ -1,6 +1,6 @@
 package Ubic::Credentials::OS::POSIX;
-BEGIN {
-  $Ubic::Credentials::OS::POSIX::VERSION = '1.38_01';
+{
+  $Ubic::Credentials::OS::POSIX::VERSION = '1.43_01';
 }
 
 use strict;
@@ -245,6 +245,11 @@ sub set {
     unless ($self->_groups_equal($), "@effective_gid")) {
         die "Failed to set effective gid to @effective_gid: $!";
     }
+    my $new_euid = $self->effective_user_id;
+    $> = $new_euid;
+    unless ($> == $new_euid) {
+        die "Failed to set effective uid to $new_euid: $!";
+    }
     my @real_gid = $self->real_group_id;
     $( = $real_gid[0];
     unless ($self->_groups_equal($(, "@real_gid")) {
@@ -255,11 +260,13 @@ sub set {
     unless ($< == $new_ruid) {
         die "Failed to set real uid to $new_ruid: $!";
     }
-    my $new_euid = $self->effective_user_id;
-    $> = $new_euid;
-    unless ($> == $new_euid) {
-        die "Failed to set effective uid to $new_euid: $!";
-    }
+}
+
+sub as_string {
+    my $self = shift;
+    my $user = $self->user;
+    my ($group) = $self->group; # ignore complementary groups for the sake of readability
+    return "$user:$group";
 }
 
 
@@ -274,7 +281,7 @@ Ubic::Credentials::OS::POSIX - POSIX-specific credentials implementation
 
 =head1 VERSION
 
-version 1.38_01
+version 1.43_01
 
 =head1 METHODS
 
